/*************************************************************************
  WhtSpc      Displays whitespace, bookmarks, and more.

  Author:     Chris Antos

  Date:       06/17/97
              05/19/99  added EOL, more configuration options
              04/12/02  configure right margin file types (SW Rienstra)
                        default = all files == '' (empty string)
                        Bookmark character -> bookmark id letter (a-z)

  Overview:

  WHTSPC adds a few handy visual elements, such as whitespace, bookmarks,
  a cursorline indicator, and a right margin indicator.  Each of these can
  be toggled on/off from a handy menu.


  Keys:       (none)


  Usage notes:

  Execute this macro to show a configuration menu where you can change the
  settings.


  Copyright (none) - FreeWare.

*************************************************************************/


// WHTSPC.S -----------------------------------------------------------------
// by Chris Antos
//
// Various enhancements to the TSE display, including displaying whitespaces
// on the cursorline.
//
// Execute the macro to display the options menu.



string c_stSection[] = "WHTSPC"
string c_stBookmarks[] = "Bookmarks"
string c_stBookmarkAttr[] = "BookmarkAttr"
string c_stBookmarkAttrTransparent[] = "BookmarkAttrTransparent"
string c_stHiliteBookmarks[] = "HiliteBookmarks"
string c_stHiliteBookmarksAttr[] = "HiliteBookmarksAttr"
string c_stHiliteBookmarksAttrTransparent[] = "HiliteBookmarksAttrTransparent"
string c_stSidechar[] = "CursorLine"
string c_stSidecharChr[] = "CursorLineChr"
string c_stSidecharAttr[] = "CursorLineAttr"
string c_stSidecharAttrTransparent[] = "CursorLineAttrTransparent"
string c_stMargin[] = "Margin"
string c_stWhitespace[] = "Whitespace"
string c_stSpaceChr[] = "WhitespaceSpaceChr"
string c_stTabChr[] = "WhitespaceTabChr"
string c_stEOL[] = "EOL"
string c_stEOLChr[] = "EOLChr"
string c_stHiliteWhitespace[] = "HiliteWhitespace"
string c_stWhitespaceAttr[] = "WhitespaceAttr"
string c_stWhitespaceAttrTransparent[] = "WhitespaceAttrTransparent"
string c_stMarginExts[] = "MarginFileExtensions"

integer g_fBookmarks
integer g_attrBookmark
integer g_fBookmarkTransparent
integer g_fHiliteBookmarks
integer g_attrHiliteBookmarksAttr
integer g_fHiliteBookmarksTransparent
integer g_fSidechar
integer g_chSidechar
integer g_attrSidechar
integer g_fSidecharTransparent
integer g_fMargin
integer g_fWhitespace
integer g_chSpace
integer g_chTab
integer g_fEOL
integer g_chEOL
integer g_fHiliteWhitespace
integer g_attrWhitespaceAttr
integer g_fWhitespaceAttrTransparent

integer g_fChanged

string  g_stMarginExts[255]
// originally: string c_stMarginExts[] = ".c.h.cpp.hpp.cxx.hxx.rc.rc2.idl.odl.s.si.ui.inc.asm.bat.btm.txt.pas.hlp.pl.vbs."

proc mPutOemChrXY(integer x, integer y, integer ch, integer attr, integer f3D)
	PutOemStrXY(x, y, Chr(ch), attr, iif(f3D, 1, 0))
end

proc mPutOemStrXY(integer x, integer y, string st, integer attr, integer f3D)
	PutOemStrXY(x, y, st, attr, iif(f3D, 1, 0))
end

integer proc FUse3D()
	return(Query(SpecialEffects) & _USE_3D_CHARS_)
end

#define COLOR_WIDTH 2
integer proc PickColor(var integer attr)
	string s[16*COLOR_WIDTH]
	string a[16*COLOR_WIDTH]
	integer i, j
	integer n = attr
	integer ch
	integer fRet = FALSE

	i = WhereXAbs()
	j = WhereYAbs()+1
	if i+(16*COLOR_WIDTH+2-1) > Query(ScreenCols)
		i = Query(ScreenCols)-(16*COLOR_WIDTH+2-1)
	endif
	if j+(18-1) > Query(ScreenRows)
		j = Query(ScreenRows)-(18-1)
	endif

	PopWinOpen(i, j, i+(16*COLOR_WIDTH+2-1), j+(18-1), 1, "Select Color",
			Query(CurrWinBorderAttr))

	for i = 0 to 255 by 16
		s = ""
		a = ""
		for j = 0 to 15
			s = s + Format(i+j:COLOR_WIDTH:"0":16)
			a = a + Format("":COLOR_WIDTH:Chr(i+j))
		endfor
		PutStrAttrXY(1, i/16+1, s, a)
	endfor

	i = (n mod 16)
	j = n/16

	loop
		// position cursor
		GotoXY((i+1)*COLOR_WIDTH, j+1)

		// process keys
		ch = GetKey()
		case ch
			when <Enter>
				// ok
				attr = j*16 + i
				fRet = TRUE
				break
			when <Escape>
				// cancel
				break
			when <CursorUp>, <GreyCursorUp>
				if j > 0
					j = j - 1
				else
					j = 15
				endif
			when <CursorDown>, <GreyCursorDown>
				if j < 15
					j = j + 1
				else
					j = 0
				endif
			when <CursorLeft>, <GreyCursorLeft>
				if i > 0
					i = i - 1
				else
					i = 15
				endif
			when <CursorRight>, <GreyCursorRight>
				if i < 15
					i = i + 1
				else
					i = 0
				endif
			when <Home>, <GreyHome>
				i = 0
				j = 0
			when <End>, <GreyEnd>
				i = 15
				j = 15
			when <Ctrl Home>, <Ctrl GreyHome>
			when <Ctrl End>, <Ctrl GreyEnd>
			when <PgUp>, <GreyPgUp>
			when <PgDn>, <GreyPgDn>
			when <Ctrl PgUp>, <Ctrl GreyPgUp>
			when <Ctrl PgDn>, <Ctrl GreyPgDn>
		endcase
	endloop

	PopWinClose()
	return (fRet)
end


integer proc Transparent(integer fTransparent, integer attrNew, integer attrCurrent)
	return (iif(fTransparent, (attrNew & 0x0f) | (attrCurrent & 0xf0), attrNew))
end


proc DrawBookmarks(integer attrBorder)
	integer i, id, ln, lpos, xofs, row
	integer nTop, nBottom
	integer cid = GetBufferId()
	integer attr

	if g_fBookmarks or g_fHiliteBookmarks
		nTop = CurrLine() - CurrRow() + 1
		nBottom = nTop + Query(WindowRows)
		attr = Transparent(g_fBookmarkTransparent, g_attrBookmark, attrBorder)

		if Query(DisplayBoxed) == 2 or
				(Query(DisplayBoxed) == 1 and Query(MouseEnabled))
			// draw bookmark indicators
			for i = Asc('a') to Asc('z')
				if isBookMarkSet(Chr(i)) and
						GetBookMarkInfo(Chr(i), id, ln, lpos, xofs, row) and
						id == cid and ln >= nTop and
						ln < nBottom
					if g_fBookmarks
						#if 0
						VGotoXYAbs(Query(WindowX1)-1, Query(WindowY1)+ln-nTop)
						mPutStr(Chr(i), attr)
						#else
						mPutOemChrXY(Query(WindowX1)-1, Query(WindowY1)+ln-nTop,
									 i, attr, FALSE)
						#endif
					endif
					if g_fHiliteBookmarks
						VGotoXYAbs(Query(WindowX1), Query(WindowY1)+ln-nTop)
						PutAttr(g_attrHiliteBookmarksAttr, Query(WindowCols))
					endif
				endif
			endfor
		endif
	endif
end


proc DrawSidechar(integer x, integer y, integer attrBorder)
	if g_fSidechar
		#if 0
		VGotoXYAbs(x, y)
		mPutStr(Chr(g_chSidechar),
				Transparent(g_fSidecharTransparent, g_attrSidechar, attrBorder))
		#else
		mPutOemChrXY(x, y, g_chSidechar, Transparent(g_fSidecharTransparent, g_attrSidechar, attrBorder), FALSE)
		#endif
	endif
end


integer proc DrawLeftBorder()
	string s[1]	= ""
	string a[1]	= ""
	integer x = Query(WindowX1)-1
	integer y = Query(WindowY1)
	integer rows = Query(WindowRows)
	integer fOk = FALSE
	integer i

	if Query(DisplayBoxed) == 2 or
			(Query(DisplayBoxed) == 1 and Query(MouseEnabled))
		Window(1, 1, Query(ScreenCols), Query(ScreenRows))

		// verify this is left border
		fOk = TRUE
		VGotoXYAbs(x, y)
		GetStr(s, 1)
		if Asc(s) == 30/**/
			VGotoXYAbs(x, y+rows-1)
			GetStr(a, 1)
			fOk = not (Asc(a) == 31/**/)
		endif

		// look for border type and attr
		if fOk
			fOk = FALSE
			for i = 0 to rows-1
				VGotoXYAbs(x, y+i)
				GetStrAttr(s, a, 1)
				if Asc(s) in 179/**/, 186/**/, 219/**/, 222/**/
					fOk = TRUE
					break
				endif
			endfor
		endif

		// if found border type and attr, draw stuff on the border
		if fOk
			// redraw the left edge, to erase old sidechar/bookmarks
			#if 0
			Set(Attr, Asc(a))
			VGotoXYAbs(x, y)
			PutCharV(s, rows)
			#else
			for i = y to y + rows - 1
				mPutOemChrXY(x, i, Asc(s[1]), Asc(a[1]), FUse3D())
			endfor
			#endif

			// draw sidechar
			DrawSidechar(x, y + CurrRow() - 1, Asc(a))

			// draw bookmarks
			DrawBookmarks(Asc(a))
		endif

		FullWindow()
	endif

	return(fOk)
end


// DrawWhitespace()
// this is more complex than it would seem.
integer g_idWindows = 0
proc DrawWhitespace(integer fDraw)
	string s[255] = ""
	string a[255] = ""
	integer xofs = CurrXoffset()
	integer topln, row, cid
	integer i
	string st[32]
	integer ch
	integer attr
	integer boxedOffset = iif(Query(DisplayBoxed), 1, 2)

	if not g_fWhitespace or
			CurrLine() > NumLines() or
			DisplayMode() <> _DISPLAY_TEXT_ or
			BinaryMode() <> 0
		return()
	endif

	// get string from screen
	GetStrAttrXY(Query(WindowX1), Query(WindowY1)+CurrRow()-boxedOffset, s, a, Query(WindowCols))
	PushPosition()

	// fix trailing whitespace
	EndLine()
	if CurrCol()-xofs <= Query(WindowCols)
		s = SubStr(s, 1, CurrCol()-xofs-1)
		s = Format(s:-Query(WindowCols):" ")
	endif

	// draw whitespace characters
	GotoColumn(xofs+1)
	repeat
		i = CurrCol()-xofs
		case CurrChar()
			when 32
				ch = iif(fDraw, g_chSpace, Asc(" "))
				attr = Asc(a[i])
				if g_fHiliteWhitespace and CurrPos() > PosLastNonWhite()
					attr = Transparent(g_fWhitespaceAttrTransparent, g_attrWhitespaceAttr, attr)
				endif
				mPutOemChrXY(Query(WindowX1) + i - 1, Query(WindowY1) + CurrRow() - boxedOffset, ch, attr, FALSE)
			when 9
				i = (((CurrCol() - 1) / Query(TabWidth)) + 1) * Query(TabWidth) - xofs
				ch = 0
				attr = Asc(a[i])
				if i <= Query(WindowCols)
					ch = iif(fDraw, g_chTab, Asc(" "))
				endif
				if g_fHiliteWhitespace and CurrPos() > PosLastNonWhite()
					attr = Transparent(g_fWhitespaceAttrTransparent, g_attrWhitespaceAttr, attr)
				endif
				mPutOemChrXY(Query(WindowX1) + i - 1, Query(WindowY1) + CurrRow() - boxedOffset, ch, attr, FALSE)
			when _AT_EOL_
				if g_fEOL
					ch = iif(fDraw, g_chEOL, Asc(" "))
					attr = Asc(a[i])
					if g_fHiliteWhitespace
						attr = Transparent(g_fWhitespaceAttrTransparent, g_attrWhitespaceAttr, attr)
					endif
					mPutOemChrXY(Query(WindowX1) + i - 1, Query(WindowY1) + CurrRow() - boxedOffset, ch, attr, FALSE)
				endif
				break
			when _BEYOND_EOL_
				break
		endcase
		Right()
	until i >= Query(WindowCols)

	// put string to screen
	PopPosition()
	//PutStrAttrXY(Query(WindowX1), Query(WindowY1)+CurrRow()-1, s, a)

	// update previous line if CursorAttr == TextAttr
	if fDraw and Query(CursorAttr) == Query(TextAttr)
		// get current info
		row = CurrRow()
		topln = CurrLine() - CurrRow() + 1
		cid = GetBufferId()

		// goto/create window info buffer
		if g_idWindows
			GotoBufferId(g_idWindows)
		else
			g_idWindows = CreateTempBuffer()
			do 32 times			// actual max is 9, allow for growth
				AddLine()
			enddo
		endif

		// check if need to force redraw
		GotoLine(WindowId())
		st = GetText(1, CurrLineLen())
		if row <> Val(GetToken(st, " ", 1)) and
				topln == Val(GetToken(st, " ", 2)) and
				xofs == Val(GetToken(st, " ", 3)) and
				cid == Val(GetToken(st, " ", 4))
			GotoBufferId(cid)
			PushPosition()
			GotoRow(Val(GetToken(st, " ", 1)))
			DrawWhitespace(FALSE)
			PopPosition()
		endif

		// record current window info
		GotoBufferId(g_idWindows)
		BegLine()
		KillToEol()
		InsertText(Format(row; topln; xofs; cid))
		GotoBufferId(cid)
	endif
end



integer proc FMarginFile()
	return ((Length(CurrExt()) and Pos(CurrExt()+".", g_stMarginExts) or g_stMarginExts == '') and
			DisplayMode() == _DISPLAY_TEXT_)
end


proc DrawMargin(integer col, string ch)
	integer x = col-CurrXoffset()
	integer y
	string s[1] = ""
	string a[1] = ""
	integer boxedOffset = iif(Query(DisplayBoxed), 1, 2)

	if x >= 1 and x <= Query(WindowCols)
		for y = 1 to Query(WindowRows)
			VGotoXY(Query(WindowX1)+x, Query(WindowY1)+y-boxedOffset)
			GetStrAttr(s, a, 1)
			if Asc(s) == 32
				mPutOemChrXY(VWhereX(), VWhereY(), Asc(ch), iif(Asc(a) & 0xf0, Asc(a) & 0xf0, 0x07), FALSE)
			endif
		endfor
	endif
end


integer g_colMargin = 0

proc Idle()
	if Query(RightMargin) <> g_colMargin
		g_colMargin = Query(RightMargin)
		UpdateDisplay(_ALL_WINDOWS_REFRESH_)
	endif
end


proc AfterUpdateDisplay()
	integer fMargin

	if BufferType() == _NORMAL_
		// draw stuff on left border
		DrawLeftBorder()

		// whitespace
		DrawWhitespace(TRUE)

		// vertical margin lines
		fMargin = FMarginFile()
#if 0
		if g_fMargin80 and fMargin
			DrawMargin(80, "")
		endif
#endif
		if g_fMargin and fMargin and Query(RightMargin) <> 80
			DrawMargin(Query(RightMargin), "")
		endif
	endif
end


proc GetSettings()
	g_fBookmarks = GetProfileInt(c_stSection, c_stBookmarks, TRUE)
	g_attrBookmark = GetProfileInt(c_stSection, c_stBookmarkAttr, Color(blink blue on white))
	g_fBookmarkTransparent = GetProfileInt(c_stSection, c_stBookmarkAttrTransparent, FALSE)

	g_fHiliteBookmarks = GetProfileInt(c_stSection, c_stHiliteBookmarks, FALSE)
	g_attrHiliteBookmarksAttr = GetProfileInt(c_stSection, c_stHiliteBookmarksAttr, Color(blink blue on white))
	g_fHiliteBookmarksTransparent = GetProfileInt(c_stSection, c_stHiliteBookmarksAttrTransparent, FALSE)

	g_fMargin = GetProfileInt(c_stSection, c_stMargin, TRUE)
	g_stMarginExts = GetProfileStr(c_stSection, c_stMarginExts, "")

	g_fWhitespace = GetProfileInt(c_stSection, c_stWhitespace, TRUE)
	g_chSpace = GetProfileInt(c_stSection, c_stSpaceChr, 250)
	g_chTab = GetProfileInt(c_stSection, c_stTabChr, 170)
	g_chEOL = GetProfileInt(c_stSection, c_stEOLChr, 20)

	g_fHiliteWhitespace = GetProfileInt(c_stSection, c_stHiliteWhitespace, FALSE)
	g_attrWhitespaceAttr = GetProfileInt(c_stSection, c_stWhitespaceAttr, Color(bright red on black))
	g_fWhitespaceAttrTransparent = GetProfileInt(c_stSection, c_stWhitespaceAttrTransparent, TRUE)
	g_fEOL = GetProfileInt(c_stSection, c_stEOL, FALSE)

	g_fSidechar = GetProfileInt(c_stSection, c_stSidechar, TRUE)
	g_chSidechar = GetProfileInt(c_stSection, c_stSidecharChr, 16)
	g_attrSidechar = GetProfileInt(c_stSection, c_stSidecharAttr, Color(bright red on black))
	g_fSidecharTransparent = GetProfileInt(c_stSection, c_stSidecharAttrTransparent, TRUE)
end


proc WriteSettings()
	WriteProfileInt(c_stSection, c_stBookmarks, g_fBookmarks)
	WriteProfileInt(c_stSection, c_stBookmarkAttr, g_attrBookmark)
	WriteProfileInt(c_stSection, c_stBookmarkAttrTransparent, g_fBookmarkTransparent)

	WriteProfileInt(c_stSection, c_stHiliteBookmarks, g_fHiliteBookmarks)
	WriteProfileInt(c_stSection, c_stHiliteBookmarksAttr, g_attrHiliteBookmarksAttr)
	WriteProfileInt(c_stSection, c_stHiliteBookmarksAttrTransparent, g_fHiliteBookmarksTransparent)

	WriteProfileInt(c_stSection, c_stMargin, g_fMargin)
	WriteProfileStr(c_stSection, c_stMarginExts, g_stMarginExts)

	WriteProfileInt(c_stSection, c_stWhitespace, g_fWhitespace)
	WriteProfileInt(c_stSection, c_stSpaceChr, g_chSpace)
	WriteProfileInt(c_stSection, c_stTabChr, g_chTab)
	WriteProfileInt(c_stSection, c_stEOLChr, g_chEOL)

	WriteProfileInt(c_stSection, c_stHiliteWhitespace, g_fHiliteWhitespace)
	WriteProfileInt(c_stSection, c_stWhitespaceAttr, g_attrWhitespaceAttr)
	WriteProfileInt(c_stSection, c_stWhitespaceAttrTransparent, g_fWhitespaceAttrTransparent)
	WriteProfileInt(c_stSection, c_stEOL, g_fEOL)

	WriteProfileInt(c_stSection, c_stSidechar, g_fSidechar)
	WriteProfileInt(c_stSection, c_stSidecharChr, g_chSidechar)
	WriteProfileInt(c_stSection, c_stSidecharAttr, g_attrSidechar)
	WriteProfileInt(c_stSection, c_stSidecharAttrTransparent, g_fSidecharTransparent)
end


string proc OnOffStr(integer f)
	return(iif(f, "On", "Off"))
end


proc ToggleVar(var integer f)
	f = not f
	g_fChanged = TRUE
end

proc GetString(var string s)
     string ss[255] = s
     if Read(ss)
        s = ss
        g_fChanged = TRUE
     endif
end  GetString

#if 0
proc ReadChr(var integer ch)
	string st[5] = Str(ch)

	if ReadNumeric(st) and Val(st) in 0..255
		ch = Val(st)
		g_fChanged = TRUE
	endif
end
#endif


proc GetColor(var integer n)
	if PickColor(n)
		g_fChanged = TRUE
	endif
end


proc drawAscii()
	mPutOemStrXY(VWhereX(), VWhereY(), GetText(1,255), Query(Attr), FALSE)
	ClrEol()
end


// mAsciiChart
// display ASCII chart and returns selected character; <Esc> to abort.
proc GetAscii(var integer ch)
	integer i
	integer cid
	integer chartid

	cid = GetBufferId()
	chartid = CreateTempBuffer()

	if chartid
		i = 0
		while AddLine(Format(i:5, Str(i, 16):4, Chr(i):4)) and i < 255
			i = i + 1
		endwhile
		GotoLine(ch + 1)
		ScrollToCenter()
		HookDisplay(drawAscii,,,)
		if List("DEC HEX Char", 20)
			ch = CurrLine() - 1
			g_fChanged = TRUE
		endif
		UnHookDisplay()
	endif

	GotoBufferId(cid)
	AbandonFile(chartid)
end


menu Options()
	title = "WHTSPC Options"
	history

	"&Whitespace" [OnOffStr(g_fWhitespace):3], ToggleVar(g_fWhitespace), CloseAllAfter, "Show whitespace on cursor line."
	"  Space character" [Chr(g_chSpace):1], GetAscii(g_chSpace), CloseAllAfter
	"  Tab character" [Chr(g_chTab):1], GetAscii(g_chTab), CloseAllAfter
	"  EOL character" [Chr(g_chEOL):1], GetAscii(g_chEOL), CloseAllAfter
	"  Show EOL" [OnOffStr(g_fEOL):3], ToggleVar(g_fEOL), CloseAllAfter, "Show EOL marker on cursor line."
	"Hilite Trailing Whitespace" [OnOffStr(g_fHiliteWhitespace):3], ToggleVar(g_fHiliteWhitespace), CloseAllAfter, "Hilite trailing whitespace to make it more visible."
	"  Hilite attribute...", GetColor(g_attrWhitespaceAttr), CloseAllAfter
	"  Transparent attribute" [OnOffStr(g_fWhitespaceAttrTransparent):3], ToggleVar(g_fWhitespaceAttrTransparent), CloseAllAfter
	"&Bookmarks" [OnOffStr(g_fBookmarks):3], ToggleVar(g_fBookmarks), CloseAllAfter, "Display a marker for bookmarked lines, on the left window border."
	//"  Marker attribute" [g_attrBookmark:3], GetColor(g_attrBookmark), CloseAllAfter
	"  Marker attribute...", GetColor(g_attrBookmark), CloseAllAfter
	"  Transparent attribute" [OnOffStr(g_fBookmarkTransparent):3], ToggleVar(g_fBookmarkTransparent), CloseAllAfter
	"&Hilite Bookmarks" [OnOffStr(g_fHiliteBookmarks):3], ToggleVar(g_fHiliteBookmarks), CloseAllAfter, "Hilite lines that are bookmarked."
	"  Hilite attribute...", GetColor(g_attrHiliteBookmarksAttr), CloseAllAfter
//$ todo: implement this
//	"  Transparent attribute" [OnOffStr(g_fHiliteBookmarksTransparent):3], ToggleVar(g_fHiliteBookmarksTransparent), CloseAllAfter
	"&Cursor Line" [OnOffStr(g_fSidechar):3], ToggleVar(g_fSidechar), CloseAllAfter, "Display a marker for the current line, on the left window border."
	"  Marker character" [Chr(g_chSidechar):1], GetAscii(g_chSidechar), CloseAllAfter
	//"  Marker attribute" [g_attrSidechar:3], GetColor(g_attrSidechar), CloseAllAfter
	"  Marker attribute...", GetColor(g_attrSidechar), CloseAllAfter
	"  Transparent attribute" [OnOffStr(g_fSidecharTransparent):3], ToggleVar(g_fSidecharTransparent), CloseAllAfter
	"&Margin" [OnOffStr(g_fMargin):3], ToggleVar(g_fMargin), CloseAllAfter, "Display a vertical line at the right margin."
	"&Margin file types" [g_stMarginExts:15], GetString(g_stMarginExts), CloseAllAfter, "File types that show right margin."
end


proc DoOptions()
	g_fChanged = FALSE

	// looping allows us to refresh the display after each change
	while Options()
		UpdateDisplay(_ALL_WINDOWS_REFRESH_)
	endwhile

	// if anything changed, write the settings to the ini file
	if g_fChanged
		WriteSettings()
		UpdateDisplay(_ALL_WINDOWS_REFRESH_)
	endif
end


proc WhenLoaded()
	GetSettings()
	Hook(_AFTER_UPDATE_DISPLAY_, AfterUpdateDisplay)
	Hook(_IDLE_, Idle)
end


proc WhenPurged()
	if g_idWindows
		AbandonFile(g_idWindows)
	endif
end


proc Main()
	DoOptions()
end


public proc WHTSPC_DrawWhitespace()
	DrawWhitespace(TRUE)
end


